@@ -19,6 +19,7 @@ var g_telemetry_MEASValue_Sequencer = 2688 + parseInt(g_SequencerIndex, 10);
 initPage();
 
 function initPage(){
+	
 	initScrollbars('List_Container');
 
 
@@ -26,7 +27,7 @@ function initPage(){
 	$('#Add_Button').bind("click", function(){AddItem(1);});
 	$('#Delete_Button').bind("click", function(){toggleDelete();});
 	$('#Navi_Button').removeAttr("href");
-	$('#Navi_Button').bind("click", function(){toggleARD('1.5.0__Sequencers.html');});
+	$('#Navi_Button').bind("click", function(){toggleARD('1.5.0__Sequencers.html?SequencerIndex=' + g_SequencerIndex);});
 	$('#Sequencer_Block').bind("click", function(){toggleListView();});
 	$('#Sequencer_Full').bind("click", function(){toggleListView();});
 
